package org.graphavik.api.example;

import com.tinkerpop.blueprints.Direction;
import org.graphavik.api.annotations.GraphId;
import org.graphavik.api.annotations.GraphProperty;
import org.graphavik.api.annotations.Indexed;
import org.graphavik.api.annotations.NodeEntity;
import org.graphavik.api.annotations.RelatedTo;

import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Base class for all intelligent creatures.
 *
 * @author Michail Nikolaev
 * @since <b>version 0.1</b> <i>created: 07.10.12</i>
 */
@NodeEntity
public class AbstractIntelligentCreature {
    public static final String KNOW_TYPE = "KNOWS";
    public static final String NAME_FILED = "NAME";
    @GraphId
    private Object id;
    // default OUT direction used
    @RelatedTo(type = KNOW_TYPE)
    private Set<AbstractIntelligentCreature> knows = new HashSet<AbstractIntelligentCreature>();
    // annotated and method level
    private Set<AbstractIntelligentCreature> knowsMe;
    @RelatedTo(type = KNOW_TYPE, direction = Direction.BOTH)
    private Collection<AbstractIntelligentCreature> knowable;
    // default name of relation used ("loves")
    @RelatedTo
    private List<AbstractIntelligentCreature> loves;

    @RelatedTo(type = "loves", direction = Direction.IN)
    private Iterable<AbstractIntelligentCreature> lovesMe;

    @Indexed("name_index")
    @GraphProperty(mappedTo = NAME_FILED)
    private String name;

    // optional annotation not set
    private AbstractIntelligentCreature mother;
    private AbstractIntelligentCreature father;

    public Object getId() {
        return id;
    }

    public void setId(Object id) {
        this.id = id;
    }

    public Set<AbstractIntelligentCreature> getKnows() {
        return knows;
    }

    public void setKnows(Set<AbstractIntelligentCreature> knows) {
        this.knows = knows;
    }

    @RelatedTo(direction = Direction.IN, type = KNOW_TYPE)
    public Set<AbstractIntelligentCreature> getKnowsMe() {
        return knowsMe;
    }

    public AbstractIntelligentCreature getMother() {
        return mother;
    }

    public void setMother(AbstractIntelligentCreature mother) {
        this.mother = mother;
    }

    public AbstractIntelligentCreature getFather() {
        return father;
    }

    public void setFather(AbstractIntelligentCreature father) {
        this.father = father;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}
