package org.graphavik.api.example.traversal;

import com.tinkerpop.blueprints.Direction;
import com.tinkerpop.blueprints.Edge;
import com.tinkerpop.blueprints.Graph;
import com.tinkerpop.blueprints.Vertex;
import org.graphavik.api.example.AbstractIntelligentCreature;
import org.graphavik.api.traversal.Traversal;

import java.util.HashSet;
import java.util.Set;

/**
 * Traversal to get names of creatures which are knows me.
 *
 * @author Michail Nikolaev
 * @since <b>version 0.1</b> <i>created: 09.10.12</i>
 */
public class KnowsMeNames implements Traversal<String> {
    @Override
    public Iterable<String> processVertex(String[] params, Vertex vertex, Graph graph)
            throws UnsupportedOperationException {
        Iterable<Vertex> vertexes =
                vertex.query().direction(Direction.IN).labels(AbstractIntelligentCreature.KNOW_TYPE).vertices();
        Set<String> names = new HashSet<String>();
        for (Vertex v : vertexes) {
            Object name = v.getProperty(AbstractIntelligentCreature.NAME_FILED);
            if (name != null) {
                names.add(name.toString());
            }
        }
        return names;
    }

    @Override
    public Iterable<String> processEdge(String[] params, Edge edge, Graph graph) throws UnsupportedOperationException {
        throw new UnsupportedOperationException();
    }

    @Override
    public Class<String> getTargetClass() {
        return String.class;
    }
}
