package org.graphavik.api.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation to specify property will be filled with ID from graph.
 * <p/>
 * You may try to assign ID to property before persisting entity. In such case it is a recommendation for the identifier
 * to use and may be ignored by database. Actual Java type of ID depends on concrete implementation, so it is
 * recommended to use Object for it.
 * <p/>
 * Check {@link com.tinkerpop.blueprints.Graph#getFeatures()} and {@link com.tinkerpop.blueprints.Features#ignoresSuppliedIds}
 * for details.
 * <p/>
 * <b>TODO(Michail Nikolaev): write about conversion services</b>
 *
 * @author Michail Nikolaev
 * @see com.tinkerpop.blueprints.Graph#getFeatures()
 * @since <b>version 0.1</b> <i>created: 06.10.12</i>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.FIELD, ElementType.METHOD })
public @interface GraphId {
}
