package org.graphavik.api.annotations;

import org.graphavik.api.traversal.Traversal;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation to declare {@link java.lang.Iterable} which will filled by traversal provided.
 * <p/>
 * Provided collection is readonly. Allowed only in {@link NodeEntity} classes. It is legal to annotate both {@link
 * NodeEntity} and {@link RelationshipEntity} collections.
 * <p/>
 * <b>Warning</b>: incorrectly implemented query may lead to errors during execution and mapping.
 * <p/>
 *
 * @author Michail Nikolaev
 * @since <b>version 0.1</b> <i>created: 09.10.12</i>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.FIELD, ElementType.METHOD })
public @interface GraphTraversal {
    /**
     * @return parameters passed to traversal builder.
     */
    String[] params() default { };

    /**
     * @return implementation of query filler to be executed.
     */
    Class<? extends Traversal> value();
}
