package org.graphavik.api.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Declared Gremlin language query to be executed from this node. Allowed only of {@link NodeEntity} classes and for
 * {@link java.lang.Iterable} field.
 * <p/>
 * Example of query: {@code @Query(value = "_().out('knows').has('name', ${name}).out(located).has('name', ${0})",
 * params =  "Minsk")}. As you can see it is possible to write ${propertyName} and ${0} to substitute value of property
 * name or parameter from {@link org.graphavik.api.annotations.Query#params()} accordingly.
 * <p/>
 * <b>Note</b>: be accurate with type mapping of query, see {@link GraphTraversal} for details.
 * <p/>
 * TODO(Michail Nikolaev): write about conversion services
 *
 * @author Michail Nikolaev
 * @see GraphTraversal
 * @since <b>version 0.1</b> <i>created: 10.10.12</i>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.FIELD, ElementType.METHOD })
public @interface Query {
    String value();

    String[] params() default { };
}
