package org.graphavik.api.annotations;

import com.tinkerpop.blueprints.Direction;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation to declared one-to-many and one-to-one relationships between {@link NodeEntity}. Optional.
 * <p/>
 * Allowed to add or remove element (from collection, or set null to the field) to add or remove relations accordingly.
 * It is legal to annotate {@link java.lang.Iterable}.
 *
 * @author Michail Nikolaev
 * @see NodeEntity
 * @since <b>version 0.1</b> <i>created: 07.10.12</i>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.FIELD, ElementType.METHOD })
public @interface RelatedTo {
    /**
     * @return name of relation, optional (field name my be used).
     */
    String type() default "";

    /**
     * @return direction of relation.
     */
    Direction direction() default Direction.OUT;
}
